Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(778)

Unified Diff: ash/wm/workspace/workspace_layout_manager_unittest.cc

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/workspace/workspace_layout_manager_unittest.cc
diff --git a/ash/wm/workspace/workspace_layout_manager_unittest.cc b/ash/wm/workspace/workspace_layout_manager_unittest.cc
index 24f6dbf6181f604e847c93660495a93f0fb1c3fe..3068e4e2c29cd1d4b3200d97a5667d0a559f8b78 100644
--- a/ash/wm/workspace/workspace_layout_manager_unittest.cc
+++ b/ash/wm/workspace/workspace_layout_manager_unittest.cc
@@ -28,8 +28,8 @@
#include "ash/test/test_session_controller_client.h"
#include "ash/test/workspace_controller_test_api.h"
#include "ash/wm/fullscreen_window_finder.h"
-#include "ash/wm/maximize_mode/maximize_mode_backdrop_delegate_impl.h"
#include "ash/wm/overview/window_selector_controller.h"
+#include "ash/wm/tablet_mode/tablet_mode_backdrop_delegate_impl.h"
#include "ash/wm/window_state.h"
#include "ash/wm/window_util.h"
#include "ash/wm/wm_event.h"
@@ -984,7 +984,7 @@ class WorkspaceLayoutManagerBackdropTest : public test::AshTestBase {
void ShowTopWindowBackdrop(bool show) {
std::unique_ptr<BackdropDelegate> backdrop;
if (show) {
- backdrop = base::MakeUnique<MaximizeModeBackdropDelegateImpl>();
+ backdrop = base::MakeUnique<TabletModeBackdropDelegateImpl>();
}
GetWorkspaceLayoutManager(default_container_)
->SetBackdropDelegate(std::move(backdrop));
@@ -1241,7 +1241,7 @@ TEST_F(WorkspaceLayoutManagerBackdropTest, BackdropTest) {
EXPECT_EQ(children[3], window3.get());
}
// Enabling the backdrop delegate for maximized mode will put the
// backdrop on the top most window.
ShowTopWindowBackdrop(true);
{
@@ -1241,7 +1241,7 @@ TEST_F(WorkspaceLayoutManagerBackdropTest, BackdropTest) {
EXPECT_EQ(children[3], window3.get());
}
- // Enabling the backdrop delegate for maximized mode will put the
+ // Enabling the backdrop delegate for tablet mode will put the
// backdrop on the top most window.
ShowTopWindowBackdrop(true);

Powered by Google App Engine
This is Rietveld 408576698